@@ -180,3 +180,6 @@ class MinBarStream(object):
 
         return bar
 
+    def close(self):
+        self._fileStream.close()
+
